Index: src/mips/stub-cache-mips.cc |
diff --git a/src/mips/stub-cache-mips.cc b/src/mips/stub-cache-mips.cc |
index 27be2d45147836c34c4ad0b2d96fe89665d6f8dc..d5b41ea7cf7c28f47cd0f1829409ae39852bab4f 100644 |
--- a/src/mips/stub-cache-mips.cc |
+++ b/src/mips/stub-cache-mips.cc |
@@ -1705,8 +1705,12 @@ Handle<Code> CallStubCompiler::CompileArrayPushCall( |
// -- sp[argc * 4] : receiver |
// ----------------------------------- |
- // If object is not an array, bail out to regular call. |
- if (!object->IsJSArray() || !cell.is_null()) return Handle<Code>::null(); |
+ // If object is not an array or is observed, bail out to regular call. |
+ if (!object->IsJSArray() || |
+ !cell.is_null() || |
+ Handle<JSArray>::cast(object)->map()->is_observed()) { |
+ return Handle<Code>::null(); |
+ } |
Label miss; |
@@ -1960,8 +1964,12 @@ Handle<Code> CallStubCompiler::CompileArrayPopCall( |
// -- sp[argc * 4] : receiver |
// ----------------------------------- |
- // If object is not an array, bail out to regular call. |
- if (!object->IsJSArray() || !cell.is_null()) return Handle<Code>::null(); |
+ // If object is not an array or is observed, bail out to regular call. |
+ if (!object->IsJSArray() || |
+ !cell.is_null() || |
+ Handle<JSArray>::cast(object)->map()->is_observed()) { |
+ return Handle<Code>::null(); |
+ } |
Label miss, return_undefined, call_builtin; |
Register receiver = a1; |